# Copyright 2015-2017 F-Secure

# Licensed under the Apache License, Version 2.0 (the "License"); you
# may not use this file except in compliance with the License.  You may
# obtain a copy of the License at

#     http://www.apache.org/licenses/LICENSE-2.0

# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
# implied.  See the License for the specific language governing
# permissions and limitations under the License.
"""Dummy image provider.

This provider does nothing but return the configured image URI string as is.

"""

import os
from see.interfaces import ImageProvider


class DummyProvider(ImageProvider):
    """Returns the configured image URI as is."""
    def __init__(self, parameters):
        super(DummyProvider, self).__init__(parameters)

    @property
    def image(self):
        return os.path.join(self.configuration.get('path'), self.name)
